@@ -1,11 +1,28 @@
+/* This file is part of Conboy.
+ * 
+ * Copyright (C) 2009 Cornelius Hald
+ *
+ * Conboy is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * Conboy is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with Conboy. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include <glib.h>
 #include <string.h>
 
-#include "search.h"
+
 #include "app_data.h"
-
-
+#include "conboy_xml.h"
+#include "search.h"
 
 /**
  * Returns a new gchar* which contains only the text, but no xml tags anymore.
@@ -15,29 +32,9 @@ static gchar*
 strip_tags(const gchar *xml_string)
 {
 	int ret;
-	AppData *app_data = app_data_get();
-	xmlTextReader *reader;
 	GString *result = g_string_new("");
+	xmlTextReader *reader = conboy_xml_get_reader_for_memory(xml_string);
 	
-	/* TODO: Duplicated code. Almose the same code is in note_buffer.c */
-	/* We try to reuse the existing xml parser. If none exists yet, we create a new one. */
-	if (app_data->reader == NULL) {
-		app_data->reader = xmlReaderForMemory(xml_string, strlen(xml_string), NULL, "UTF-8", 0);
-	}
-	
-	if (xmlReaderNewMemory(app_data->reader, xml_string, strlen(xml_string), NULL, "UTF-8", 0) != 0) {
-		g_printerr("ERROR: Cannot reuse xml parser. \n");
-		g_assert_not_reached();
-	}
-	
-	if (app_data->reader == NULL) {
-		g_printerr("ERROR: Couldn't init xml parser.\n");
-		g_assert_not_reached();
-	}
-	
-	reader = app_data->reader;
-	
-	/*xmlReaderNewMemory(reader, xml_string, strlen(xml_string), NULL, NULL, 0);*/
 	ret = xmlTextReaderRead(reader);
 	while (ret == 1) {
 		int type = xmlTextReaderNodeType(reader);
@@ -146,12 +143,15 @@ search(const gchar *query, GHashTable *result)
 
 	while (valid) {
 		gint match_count = 0;
-		Note *note;
+		ConboyNote *note;
 		gtk_tree_model_get(model, &iter, NOTE_COLUMN, &note, -1);
 		
-		/*if (has_match(note->content, words)) {*/
-			match_count = find_match_count(note->content, words);
-		/*}*/
+		gchar *content;
+		g_object_get(note, "content", &content, NULL);
+		if (content != NULL) {
+			match_count = find_match_count(content, words);
+		}
+		
 			
 		if (match_count > 0) {
 			g_hash_table_insert(result, note, GINT_TO_POINTER(match_count));
